soupsieve: A modern CSS selector implementation for Beautiful Soup.
===================================================================

Description
-----------

A modern CSS selector implementation for Beautiful Soup.

License
-------

Upstream Contact
----------------

https://pypi.org/project/soupsieve/

